<?php

namespace CsvUpload\Upload;

require_once '../lib/config.php';
require_once '../controller/auth.php';

# We advertise the maximum upload file size as per PHP configuration to save
# users the trouble of waiting for a big file being transferred only to find
# that it was too large and the transfer failed.
function max_file_size() {
  return return_bytes(ini_get('upload_max_filesize'));
}

# See http://www.php.net/ini_get
function return_bytes($val) {
  $val = trim($val);
  $last = strtolower($val[strlen($val)-1]);
  switch($last) {
      # The 'G' modifier is available since PHP 5.1.0
      case 'g':
          $val *= 1024;
      case 'm':
          $val *= 1024;
      case 'k':
          $val *= 1024;
  }

  return $val;
}

# Returns the full path to this application spool directory, used as a base
# path for many others.
function spool_dir() {
  return sys_get_temp_dir() . '/' . \CsvUpload\Config\SPOOL_DIR . '/';
}

# Returns the full path to the current user home directory (spool).
function home_dir() {
  return spool_dir() .  \CsvUpload\Auth\user_id();
}

# Returns the full path to the processing progress file for the current user.
function progress_file() {
  return spool_dir() . sprintf(\CsvUpload\Config\PROGRESS_FILE,
    \CsvUpload\Auth\user_id());
}

# Ditto for the lock file, used to signal that a processing is in progress.
function lock_file() {
  return spool_dir() .
    sprintf(\CsvUpload\Config\LOCK_FILE, \CsvUpload\Auth\user_id());
}

# Strips out the unique prefix from a file name, returning the original file
# name on the user machine.
function strip_prefix($file) {
  # [[:xdigit:]] can also be used
  preg_match('/^[0-9a-f]+\.[0-9]{8}(.*)/', $file, $matches);
  return $matches[1];
}

# Returns the list of uploaded file names for the current user.
# If full names and path are needed set the long option to TRUE.
function ls($long = FALSE) {
  $files = array();
  if ($dh = @opendir($path = home_dir())) {
    while (($file = readdir($dh)) !== false) {
      if ($file != '..' && $file != '.') {
        $files[] = $long ? "$path/$file" : strip_prefix($file);
      }
    }
    closedir($dh);
  }
  return $files;
}

# Purges the spool for the current user.
function purge() {
  rrmdir(home_dir());
}

# Recursively deletes a directory.
function rrmdir($path) {
  # This is a small sample of the functional paradigm in action :)
  return file_exists($path) ? is_file($path) ? @unlink($path)
    : array_map('CsvUpload\Upload\rrmdir', glob($path . '/*')) == @rmdir($path) : 0;
}

# vim: set filetype=php expandtab tabstop=2 shiftwidth=2 autoindent smartindent:
?>
