<?php

namespace CsvUpload\DataBase;

require_once '../model/connect.php';
require_once '../lib/config.php';
require_once '../controller/auth.php';

function recognize_header(&$header, $key) {
  $value = '@dummy';  # This will make MySQL ignore this field.
  foreach (array('mac','ssid','latitude','longitude') as $field) {
    if (stripos($header, $field) !== FALSE) {
      $value = "@$field";
      break;
    }
  }
  $header = $value;
}

# Loads a CSV file into the asp table.
# Please note the MySQL file privilege is needed
# if your database resides on the same host.
# Returns TRUE on success or FALSE on failure.
function load_csv($file) {
  if (($handle = fopen($file, 'r')) !== FALSE) {
    $format = fgetcsv($handle);

    # Read the next line just to see what kind of newline is used.
    if (($data = fgets($handle)) === FALSE) return FALSE;

    if (substr($data, -2) == "\r\n") {
      $newline = '\r\n';  # Windows
    } elseif (substr($data, -1) == "\r") {
      $newline = '\r';    # OS X
    } else {
      $newline = '\n';    # Unix
    }

    fclose($handle);

    array_walk($format, '\CsvUpload\DataBase\recognize_header');
    # Format must include all mandatory field.
    if (! in_array('@mac', $format) || ! in_array('@latitude', $format)
        || ! in_array('@longitude', $format)) {
      return FALSE;
    }
    $format = implode(', ', $format);

    # If the database server is local, let it read the CSV file directly to
    # optimize.
    $local = stripos(\CsvUpload\Config\DB_DSN, 'localhost') !== FALSE ||
      stripos(\CsvUpload\Config\DB_DSN, '127.0.0.1' !== FALSE) ? '' : 'LOCAL';

    # Note that interpolation of field list is safe from SQL injection
    # because @dummy values are substituted for unrecognized fields and
    # standard names for recognized ones. $newline must be interpolated
    # because it contains backslashes.
    $sth = dbh()->prepare(<<<EOQ
SET foreign_key_checks=0;
LOAD DATA $local INFILE :file INTO TABLE aps
FIELDS TERMINATED BY ',' LINES TERMINATED BY '$newline' IGNORE 1 LINES
($format)
SET user=:user,
mac=CONV(REPLACE(@mac, ':', ''),16,10),
ssid=IF(@ssid != '', @ssid, NULL), 
location=GeomFromText(CONCAT('POINT(', @latitude, ' ', @longitude, ')'));
SET foreign_key_checks=1;
EOQ
    );

    return $sth->execute(array(
      ':file'    => $file,
      ':user'    => \CsvUpload\Auth\user_id()
    ));
  }
}

# vim: set filetype=php expandtab tabstop=2 shiftwidth=2 autoindent smartindent:

?>
