<?php

# A web service to upload files into the logged in user spool.
# Requires authentication through the auth.php web service.
# Input: csvupload[], a multipart/form-data array of files to upload. 
# Output: if called with an HTTP referrer, it just redirects to the
# caller. If there is no referrer, it returns an array of error codes
# 0 meaning upload with success. Please see:
# http://www.php.net/manual/en/features.file-upload.errors.php
# If you are not authenticated, it returns false.

require '../controller/auth.php';
require '../controller/upload.php';
require '../lib/service.php';

# Check authentication!
if (! \CsvUpload\Auth\logged_in()) {
  json_exit();
}

if (isset($_FILES['csvupload'])) {
  # Make sure the destination dir exists. This gets created if no file is
  # selected for upload in your form, but it is not a problem.
  mkdir($home = \CsvUpload\Upload\home_dir(), 0777, true);

  # Spool uploaded files.
  foreach ($_FILES['csvupload']['error'] as $key => $error) {
    if ($error == UPLOAD_ERR_OK) {
    # Append a unique number to each file to avoid overwrites.
    # DIRECTORY_SEPARATOR is not necessary, PHP makes forward slashes to work
    # in Windows as well :)
    move_uploaded_file($_FILES['csvupload']['tmp_name'][$key],
      $home . '/' . uniqid(rand(), true) . $_FILES['csvupload']['name'][$key]);
    }
  }
}

if (isset($_SERVER['HTTP_REFERER'])) {
  header("Location: $_SERVER[HTTP_REFERER]");  
  exit;
}

json_export($_FILES['csvupload']['error']);

# vim: set filetype=php expandtab tabstop=2 shiftwidth=2 autoindent smartindent:
?>
