// E.g. see https://developer.mozilla.org/en/AJAX/Getting_Started
// and
// http://snipplr.com/view/3701/ajax-form-post-request--html-form-postsubmit-with-ajaxjavascript-exampletutorial/

window.onload = function() {
  var httpRequest;

  // http://stackoverflow.com/questions/130396/are-there-constants-in-javascript
  var PREFIX = 'CSVUPLOAD_';

  // Time interval between each state table update (milliseconds)
  var INTERVAL = 3000;

  // Either Login or Logout
  var action;

  // An interval variable
  var interval;

  // Yep, a selector like the big JavaScript libraries :)
  function $(id) {
    return document.getElementById(PREFIX + id);
  }

  var node = $('logout');
  if (node) {
    action = 'Logout';
    node.onclick = function() {
      if (confirm('Are you sure you want to logout? Any unprocessed files (if any) will be lost.')) {
        // Ajax logout request
        ajax('../service/auth.php', auth, 'action=logout');
      }
    }
  }

  if (node = $('login')) {
    action = 'Login';
    node.onsubmit = function() {
      // TODO: client side form validation can be implemented here

      // Ajax login form POST request

      // Build a query string.
      // JavaScript does not provide a facility for this. See:
      // http://stackoverflow.com/questions/316781/how-to-build-query-string-with-javascript
      var query = 'action=login&email=' + encodeURI($('email').value)
        + '&password=' + encodeURI($('password').value);

      ajax('../service/auth.php', auth, query);

      // Prevent form submission before login checking.
      return false;
    }
  }

  if (node = $('process')) {
    node.onclick = function() {
      ajax('../service/schedule.php', aps);  // no query

      // Update state every INTERVAL milliseconds.
      update();
      interval = setInterval(update, INTERVAL);
    }
  }

  function update() {
    ajax('../service/state.php', state);  // no query
  }

  function ajax(url, callback, query) {
    if (window.XMLHttpRequest) { // Mozilla, Safari, ...
        httpRequest = new XMLHttpRequest();
    } else if (window.ActiveXObject) { // IE
      try {
        httpRequest = new ActiveXObject("Msxml2.XMLHTTP");
      }
      catch (e) {
        try {
          httpRequest = new ActiveXObject("Microsoft.XMLHTTP");
        }
        catch (e) {}
      }
    }

    if (!httpRequest) {
      alert('Browser error. AJAX support missing.');
      return false;
    }

    if (typeof callback != 'undefined') {
        httpRequest.onreadystatechange = callback;
    }
    // false: synchronous; true: asynchronous
    httpRequest.open('GET', url + (query ? '?' + query : ''), false);
    httpRequest.send(null);
  }

  function auth() {
    try {
      if (httpRequest.readyState === 4) {
        if (httpRequest.status === 200) {
          //alert(httpRequest.responseText);  // DEBUG
          var response = JSON.parse(httpRequest.responseText);
          if (response) {
            window.location.reload();
          } else {
            var err = $('error'),
                msg = action + ' failed';
            if (document.all) {
              // IE
              err.innerText = msg;
            } else {
              // Mozilla, ...
              err.textContent = msg;
            }
          }
        } else {
          alert('Server error. Please retry.');
        }
      }
    }
    catch( e ) {
      alert('Communication error. Please retry.');
    }
  }

  function aps() {
    try {
      if (httpRequest.readyState === 4) {
        if (httpRequest.status === 200) {
          //alert(httpRequest.responseText);  // DEBUG
          var response = JSON.parse(httpRequest.responseText);
          if (! response) {
            alert('Processing scheduling failed');
          }
        } else {
          alert('Server error. Please retry.');
        }
      }
    }
    catch( e ) {
      alert('Communication error. Please retry.');
    }
  }

  function state() {
    try {
      if (httpRequest.readyState === 4) {
        if (httpRequest.status === 200) {
          //alert(httpRequest.responseText);  // DEBUG
          var response = JSON.parse(httpRequest.responseText);
          if (response == -1) {
            // First immediate request can be faster
            // than the processing to start server-side
            if (interval) {
              // To avoid bugging users with repeated errors.
              clearInterval(interval);
              alert('No processing in progress');
            }
          } else if (response == false) {
            clearInterval(interval);
            alert('Login failed');
          } else {
            var report = '<table>';
            var done = true;  // optimism
            for (var file in response) {
              var state = response[file];
              if (state != 'done' && state != 'error') {
                done = false;
              }

              // Remove unique prefix same as:
              // \CsvUpload\Upload\strip_prefix server side.
              // See: http://www.regular-expressions.info/javascript.html
              report += '<tr><td>' + file.replace(/^([0-9a-f]+\.[0-9]{8})/, '')
                + '</td><td>' + (state == 'processing' ?
                    '<img src="throbber.gif" alt="processing" />'
                    : state) + '</td>';
            }
            report += '</table>';

            if (done) {
              clearInterval(interval);
              report += '<a href="./">Upload other files</a>';
            }

            $('main').innerHTML = report;
          }
        } else {
          alert('Server error. Please retry.');
        }
      }
    }
    catch( e ) {
      alert('Communication error. Please retry.');
    }
  }
}

// vim: set filetype=php expandtab tabstop=2 shiftwidth=2 autoindent smartindent:
